package com.taais.biz.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.taais.common.core.core.domain.CommonResult;
import com.taais.common.core.core.page.PageResult;
import com.taais.common.excel.utils.ExcelUtil;
import com.taais.common.log.annotation.Log;
import com.taais.common.log.enums.BusinessType;
import com.taais.common.web.annotation.RepeatSubmit;
import com.taais.common.web.core.BaseController;
import com.taais.biz.domain.Data;
import com.taais.biz.domain.bo.DataBo;
import com.taais.biz.domain.vo.DataVo;
import com.taais.biz.service.IDataService;
import com.taais.system.config.ServerConfig;
import jakarta.annotation.Resource;
import jakarta.servlet.http.HttpServletResponse;
import lombok.RequiredArgsConstructor;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.util.ArrayList;
import java.util.List;

/**
 * 数据管理Controller
 *
 * @author km
 * 2024-04-22
 */
@Validated
@RequiredArgsConstructor
@RestController
@RequestMapping("/demo/data")
public class DataController extends BaseController {
    private static final Logger log = LoggerFactory.getLogger(DataController.class);
    @Resource
    private IDataService dataService;
    @Autowired
    private ServerConfig serverConfig;

    /**
     * 查询数据管理列表
     */
    @SaCheckPermission("demo:data:list")
    @GetMapping("/list")
    public CommonResult<PageResult<DataVo>> list(DataBo dataBo) {

        return CommonResult.success(dataService.selectPage(dataBo));

    }

    /**
     * 导出数据管理列表
     */
    @SaCheckPermission("demo:data:export")
    @Log(title = "数据管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DataBo dataBo) {
        List<DataVo> list = dataService.selectList(dataBo);
        ExcelUtil.exportExcel(list, "数据管理", DataVo.class, response);
    }

    /**
     * 获取数据管理详细信息
     */
    @SaCheckPermission("demo:data:query")
    @GetMapping(value = "/{id}")
    public CommonResult<DataVo> getInfo(@PathVariable Long id) {

        return CommonResult.success(dataService.selectById(id));
    }

    /**
     * 新增数据管理
     */
    @SaCheckPermission("demo:data:add")
    @Log(title = "数据管理", businessType = BusinessType.INSERT)
    @RepeatSubmit()
    @PostMapping
    public CommonResult<Void> add(@Validated @RequestBody DataBo dataBo) {
        boolean inserted = dataService.insert(dataBo);
        if (!inserted) {
            return CommonResult.fail("新增数据管理记录失败！");
        }
        return CommonResult.success();
    }

    /**
     * 修改数据管理
     */
    @SaCheckPermission("demo:data:edit")
    @Log(title = "数据管理", businessType = BusinessType.UPDATE)
    @RepeatSubmit()
    @PutMapping
    public CommonResult<Void> edit(@Validated @RequestBody DataBo dataBo) {
        Boolean updated = dataService.update(dataBo);
        if (!updated) {
            return CommonResult.fail("修改数据管理记录失败!");
        }
        return CommonResult.success();
    }

    /**
     * 删除数据管理
     */
    @SaCheckPermission("demo:data:remove")
    @Log(title = "数据管理", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public CommonResult<Void> remove(@PathVariable Long[] ids) {
        boolean deleted = dataService.deleteByIds(ids);
        if (!deleted) {
            return CommonResult.fail("删除数据管理记录失败!");
        }
        return CommonResult.success();
    }

    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response) {
        ExcelUtil.exportExcel(new ArrayList<>(), "用户数据", DataVo.class, response);
    }

    @PostMapping("/zip/upload")
    public CommonResult<Boolean> uploadZipFile(@RequestParam("file") MultipartFile file, Data dataInfo) throws Exception {
        if (file == null) {
            return CommonResult.fail("请上传.zip、.rar压缩文件。");
        }
        return dataService.uploadDataInfo(file,dataInfo);
    }
}
